@@ -1,4 +1,4 @@
 library(testthat)
 library(splithalfr)
 
-test_check("splithalfr")
+#test_check("splithalfr")
